OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Αδυναμία αποστολής μηνύματος στους ακόλουθους χρήστες: %s",
    "Preparing update" : "Προετοιμασία ενημέρωσης",
    "Turned on maintenance mode" : "Η κατάσταση συντήρησης ενεργοποιήθηκε",
    "Turned off maintenance mode" : "Η κατάσταση συντήρησης απενεργοποιήθηκε",
    "Maintenance mode is kept active" : "Η λειτουργία συντήρησης διατηρήθηκε ενεργή",
    "Updating database schema" : "Ένημέρωση σχήματος βάσης δεδομένων",
    "Updated database" : "Ενημερωμένη βάση δεδομένων",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Έλεγχος αν το σχήμα της βάσης δεδομένων μπορεί να ενημερωθεί (αυτό μπορεί να πάρει πολλή ώρα ανάλογα με το μέγεθος της βάσης δεδομένων)",
    "Checked database schema update" : "Έλεγχος ενημέρωσης σχήματος βάσης δεδομένων",
    "Checking updates of apps" : "Έλεγχος ενημερώσεων εφαρμογών",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Έλεγχος αν το σχήμα της βάσης δεδομένων για %s μπορεί να ενημερωθεί (αυτό μπορεί να πάρει πολλή ώρα ανάλογα με το μέγεθος της βάσης δεδομένων)",
    "Checked database schema update for apps" : "Έλεγχος ενημέρωσης σχήματος βάσης δεδομένων για εφαρμογές",
    "Updated \"%s\" to %s" : "Αναβαθμίστηκε \"%s\" σε %s",
    "Repair warning: " : "Προειδοποίηση διόρθωσης:",
    "Repair error: " : "Σφάλμα διόρθωσης:",
    "%s (3rdparty)" : "%s (3ου μέρους)",
    "%s (incompatible)" : "%s (ασύμβατη)",
    "Following apps have been disabled: %s" : "Οι ακόλουθες εφαρμογές έχουν απενεργοποιηθεί: %s",
    "Already up to date" : "Ήδη ενημερωμένο",
    "File is too big" : "Το αρχείο είναι πολύ μεγάλο",
    "Invalid file provided" : "Έχει δοθεί μη έγκυρο αρχείο",
    "No image or file provided" : "Δεν δόθηκε εικόνα ή αρχείο",
    "Unknown filetype" : "Άγνωστος τύπος αρχείου",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "An error occurred. Please contact your admin." : "Προέκυψε σφάλμα. Παρακαλώ επικοινωνήστε με τον διαχειριστή σας.",
    "No temporary profile picture available, try again" : "Δεν υπάρχει προσωρινή φωτογραφία προφίλ διαθέσιμη, δοκιμάστε ξανά",
    "No crop data provided" : "Δεν δόθηκαν δεδομένα περικοπής",
    "No valid crop data provided" : "Έχουν δοθεί μη έγκυρα δεδομένα περικοπής",
    "Crop is not square" : "Η περικοπή δεν εχει τετραγωνικό σχήμα",
    "Couldn't reset password because the token is invalid" : "Αδυναμία επαναφοράς κωδικού πρόσβασης καθώς το τεκμήριο είναι άκυρο",
    "Couldn't reset password because the token is expired" : "Αδυναμία επαναφοράς κωδικού πρόσβασης επειδή το token έχει λήξει",
    "Couldn't send reset email. Please make sure your username is correct." : "Αδυναμία αποστολής ηλ. μηνύματος επαναφοράς. Παρακαλώ ελέγξτε ότι το όνομα χρήστη σας είναι ορθό.",
    "%s password reset" : "%s επαναφορά κωδικού πρόσβασης",
    "Couldn't send reset email. Please contact your administrator." : "Αδυναμία αποστολής ηλ. μηνύματος επαναφοράς. Παρακαλώ επικοινωνήστε με το διαχειριστή σας.",
    "Sunday" : "Κυριακή",
    "Monday" : "Δευτέρα",
    "Tuesday" : "Τρίτη",
    "Wednesday" : "Τετάρτη",
    "Thursday" : "Πέμπτη",
    "Friday" : "Παρασκευή",
    "Saturday" : "Σάββατο",
    "Sun." : "Κυρ.",
    "Mon." : "Δευ.",
    "Tue." : "Τρί.",
    "Wed." : "Τετ.",
    "Thu." : "Πέμ.",
    "Fri." : "Παρ.",
    "Sat." : "Σαβ.",
    "Su" : "Κυ",
    "Mo" : "Δε",
    "Tu" : "Τρ",
    "We" : "Τε",
    "Th" : "Πε",
    "Fr" : "Πα",
    "Sa" : "Σα",
    "January" : "Ιανουάριος",
    "February" : "Φεβρουάριος",
    "March" : "Μάρτιος",
    "April" : "Απρίλιος",
    "May" : "Μάϊος",
    "June" : "Ιούνιος",
    "July" : "Ιούλιος",
    "August" : "Αύγουστος",
    "September" : "Σεπτέμβριος",
    "October" : "Οκτώβριος",
    "November" : "Νοέμβριος",
    "December" : "Δεκέμβριος",
    "Jan." : "Ιαν.",
    "Feb." : "Φεβ.",
    "Mar." : "Μαρ.",
    "Apr." : "Απρ.",
    "May." : "Μαι.",
    "Jun." : "Ιουν.",
    "Jul." : "Ιουλ.",
    "Aug." : "Αυγ.",
    "Sep." : "Σεπ.",
    "Oct." : "Οκτ.",
    "Nov." : "Νοε.",
    "Dec." : "Δεκ.",
    "Settings" : "Ρυθμίσεις",
    "Saving..." : "Γίνεται αποθήκευση...",
    "Dismiss" : "Απόρριψη",
    "seconds ago" : "δευτερόλεπτα πριν",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Ο σύνδεσμος για την επαναφορά του κωδικού πρόσβασής σας απεστάλη στο ηλ. ταχυδρομείο σας. Εάν δεν το παραλάβετε μέσα σε ένα εύλογο χρονικό διάστημα, ελέγξτε το φάκελο ανεπιθύμητων μηνυμάτων σας. <br>Εάν δεν βρίσκεται εκεί ρωτήστε τον τοπικό διαχειριστή σας.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Τα αρχεία σας είναι κρυπτογραφημένα. Εάν δεν έχετε ενεργοποιήσει το κλειδί επαναφοράς, δεν θα υπάρχει τρόπος να ανακτήσετε τα δεδομένα σας μετά την επαναφορά του κωδικού πρόσβασής σας.<br />Εάν δεν είστε σίγουροι για το τι θα θέλατε να κάνετε, παρακαλώ επικοινωνήστε με το διαχειριστή σας πριν συνεχίσετε. <br />Θέλετε στ' αλήθεια να συνεχίσετε;",
    "I know what I'm doing" : "Γνωρίζω τι κάνω",
    "Password can not be changed. Please contact your administrator." : "Ο κωδικός πρόσβασης δεν μπορεί να αλλάξει. Παρακαλώ επικοινωνήστε με το διαχειριστή σας.",
    "No" : "Όχι",
    "Yes" : "Ναι",
    "Choose" : "Επιλέξτε",
    "Error loading file picker template: {error}" : "Σφάλμα κατά την φόρτωση προτύπου επιλογέα αρχείων: {σφάλμα}",
    "Ok" : "Οκ",
    "Error loading message template: {error}" : "Σφάλμα φόρτωσης προτύπου μηνυμάτων: {σφάλμα}",
    "read-only" : "μόνο για ανάγνωση",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} αρχείο διαφέρει","{count} αρχεία διαφέρουν"],
    "One file conflict" : "Ένα αρχείο διαφέρει",
    "New Files" : "Νέα Αρχεία",
    "Already existing files" : "Ήδη υπάρχοντα αρχεία",
    "Which files do you want to keep?" : "Ποια αρχεία θέλετε να κρατήσετε;",
    "If you select both versions, the copied file will have a number added to its name." : "Εάν επιλέξετε και τις δυο εκδοχές, ένας αριθμός θα προστεθεί στο αντιγραφόμενο αρχείο.",
    "Cancel" : "Άκυρο",
    "Continue" : "Συνέχεια",
    "(all selected)" : "(όλα τα επιλεγμένα)",
    "({count} selected)" : "({count} επιλέχθησαν)",
    "Error loading file exists template" : "Σφάλμα κατά την φόρτωση του προτύπου \"αρχείο υπάρχει\"",
    "Very weak password" : "Πολύ αδύναμο συνθηματικό",
    "Weak password" : "Αδύναμο συνθηματικό",
    "So-so password" : "Μέτριο συνθηματικό",
    "Good password" : "Καλό συνθηματικό",
    "Strong password" : "Δυνατό συνθηματικό",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Ο διακομιστής σας δεν έχει ρυθμιστεί κατάλληλα ώστε να επιτρέπει τον συγχρονισμό αρχείων γιατί η διεπαφή WebDAV πιθανόν είναι κατεστραμμένη.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Αυτός ο διακομιστής δεν έχει ενεργή σύνδεση στο διαδίκτυο. Αυτό σημαίνει ότι κάποιες υπηρεσίες όπως η σύνδεση με εξωτερικούς αποθηκευτικούς χώρους, ειδοποιήσεις για ενημερώσεις ή η εγκατάσταση εφαρμογών 3ων δεν θα είναι διαθέσιμες. Η πρόσβαση απομακρυσμένων αρχείων και η αποστολή ειδοποιήσεων μέσω ηλεκτρονικού ταχυδρομείου μπορεί επίσης να μην είναι διαθέσιμες. Προτείνουμε να ενεργοποιήσετε την πρόσβαση στο διαδίκτυο για αυτόν το διακομιστή εάν θέλετε να χρησιμοποιήσετε όλες τις υπηρεσίες.",
    "Error occurred while checking server setup" : "Παρουσιάστηκε σφάλμα κατά τον έλεγχο της εγκατάστασης με το διακομιστή",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Ο κατάλογος δεδομένων και τα αρχεία σας είναι πιθανόν διαθέσιμα στο διαδίκτυο. Το αρχείο .htaccess δεν λειτουργεί. Σας προτείνουμε ανεπιφύλακτα να ρυθμίσετε το διακομιστή σας με τέτοιο τρόπο ώστε ο κατάλογος δεδομένων να μην είναι πλέον προσβάσιμος ή να μετακινήσετε τον κατάλογο δεδομένων εκτός του καταλόγου της ρίζας εγγράφων-document root του διακομιστή.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "H \"{header}\" κεφαλίδα HTTP δεν έχει ρυθμιστεί ώστε να ισούται με \"{expected}\". Αυτό αποτελεί ενδεχόμενο κίνδυνο ασφάλειας ή ιδιωτικότητας και συστήνουμε τη διόρθωση αυτής της ρύθμισης.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Έχετε πρόσβαση σε αυτό τον ιστότοπο μέσω HTTP. Προτείνουμε ανεπιφύλακτα να ρυθμίσετε το διακομιστή σας ώστε να απαιτεί τη χρήση HTTPS όπως περιγράφεται στις <a href=\"{docUrl}\">προτάσεις ασφαλείας</a> μας.",
    "Shared" : "Κοινόχρηστα",
    "Shared with {recipients}" : "Διαμοιράστηκε με {recipients}",
    "Error" : "Σφάλμα",
    "Error while sharing" : "Σφάλμα κατά τον διαμοιρασμό",
    "Error while unsharing" : "Σφάλμα κατά το σταμάτημα του διαμοιρασμού",
    "Error setting expiration date" : "Σφάλμα κατά τον ορισμό ημ. λήξης",
    "The public link will expire no later than {days} days after it is created" : "Ο δημόσιος σύνδεσμος θα απενεργοποιηθεί το πολύ {days} ημέρες μετά την δημιουργία του",
    "Set expiration date" : "Ορισμός ημ. λήξης",
    "Expiration" : "Λήξη",
    "Expiration date" : "Ημερομηνία λήξης",
    "Choose a password for the public link" : "Επιλέξτε κωδικό για τον δημόσιο σύνδεσμο",
    "Sending ..." : "Αποστολή...",
    "Email sent" : "Το Email απεστάλη ",
    "Resharing is not allowed" : "Ξαναμοιρασμός δεν επιτρέπεται",
    "Share link" : "Διαμοιρασμός συνδέσμου",
    "Link" : "Σύνδεσμος",
    "Password protect" : "Προστασία συνθηματικού",
    "Password" : "Συνθηματικό",
    "Allow editing" : "Επιτρέπεται η επεξεργασία",
    "Email link to person" : "Αποστολή συνδέσμου με email ",
    "Send" : "Αποστολή",
    "Shared with you and the group {group} by {owner}" : "Διαμοιράστηκε με σας και με την ομάδα {group} του {owner}",
    "Shared with you by {owner}" : "Διαμοιράστηκε με σας από τον {owner}",
    "group" : "ομάδα",
    "remote" : "απομακρυσμένα",
    "notify by email" : "ειδοποίηση με email",
    "Unshare" : "Διακοπή διαμοιρασμού",
    "can share" : "δυνατότητα διαμοιρασμού",
    "can edit" : "δυνατότητα αλλαγής",
    "create" : "δημιουργία",
    "change" : "αλλαγή",
    "delete" : "διαγραφή",
    "access control" : "έλεγχος πρόσβασης",
    "Share details could not be loaded for this item." : "Αδυναμία φόρτωσης λεπτομερειών διαμοιρασμού για αυτό το αντικείμενο.",
    "An error occured. Please try again" : "Ένα σφάλμα προέκυψε. Παρακαλώ προσπαθήστε ξανά",
    "Share" : "Διαμοιρασμός",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Διαμοιρασμός με άτομα σε άλλα ownClouds χρησιμοποιώντας την σύνταξη username@example.com/owncloud",
    "Share with users or groups …" : "Διαμοιρασμός με χρήστες ή ομάδες ...",
    "Share with users, groups or remote users …" : "Διαμοιρασμός με χρήστες, ομάδες ή απομακρυσμένους χρήστες ...",
    "Warning" : "Προειδοποίηση",
    "Error while sending notification" : "Σφάλμα κατά την αποστολή ειδοποίησης",
    "Delete" : "Διαγραφή",
    "Rename" : "Μετονομασία",
    "The object type is not specified." : "Δεν καθορίστηκε ο τύπος του αντικειμένου.",
    "Enter new" : "Εισαγωγή νέου",
    "Add" : "Προσθήκη",
    "Edit tags" : "Επεξεργασία ετικετών",
    "Error loading dialog template: {error}" : "Σφάλμα φόρτωσης προτύπου διαλόγων: {σφάλμα}",
    "No tags selected for deletion." : "Καμμία ετικέτα δεν επιλέχθηκε για διαγραφή.",
    "unknown text" : "άγνωστο κείμενο",
    "Hello world!" : "Γεια σου κόσμε!",
    "sunny" : "ηλιόλουστη",
    "Hello {name}, the weather is {weather}" : "Γειά σου {name}, ο καιρός είναι {weather}",
    "Hello {name}" : "Γεια σου {name}",
    "_download %n file_::_download %n files_" : ["λήψη %n αρχείου","λήψη %n αρχείων"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Η αναβάθμιση είναι σε εξέλιξη, αν φύγετε από αυτή τη σελίδα μπορεί να διακοπεί η διαδικασία σε ορισμένα περιβάλλοντα χρήσης.",
    "Updating {productName} to version {version}, this may take a while." : "Ενημέρωση του {productName} στην έκδοση {version}, αυτό μπορεί να διαρκέσει λίγη ώρα.",
    "An error occurred." : "Παρουσιάστηκε σφάλμα",
    "Please reload the page." : "Παρακαλώ επαναφορτώστε τη σελίδα.",
    "The update was unsuccessful. " : "Η ενημέρωση ήταν ανεπιτυχής.",
    "The update was successful. There were warnings." : "Η ενημέρωση ήταν επιτυχής. Υπήρχαν προειδοποιήσεις.",
    "The update was successful. Redirecting you to ownCloud now." : "Η ενημέρωση ήταν επιτυχής. Μετάβαση στο ownCloud.",
    "Searching other places" : "Έρευνα σε άλλα σημεία.",
    "No search results in other folders" : "Δεν υπάρχουν αποτελέσματα αναζήτησης σε άλλους φακέλους",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} αποτέλεσμα αναζήτησης σε άλλο φάκελο","{count} αποτελέσματα αναζήτησης σε άλλους φακέλους"],
    "Personal" : "Προσωπικά",
    "Users" : "Χρήστες",
    "Apps" : "Εφαρμογές",
    "Admin" : "Διαχείριση",
    "Help" : "Βοήθεια",
    "Error loading tags" : "Σφάλμα φόρτωσης ετικετών",
    "Tag already exists" : "Υπάρχει ήδη η ετικέτα",
    "Error deleting tag(s)" : "Σφάλμα διαγραφής ετικέτας(ων)",
    "Error tagging" : "Σφάλμα προσθήκης ετικέτας",
    "Error untagging" : "Σφάλμα αφαίρεσης ετικέτας",
    "Error favoriting" : "Σφάλμα προσθήκης στα αγαπημένα",
    "Error unfavoriting" : "Σφάλμα αφαίρεσης από τα αγαπημένα",
    "Access forbidden" : "Δεν επιτρέπεται η πρόσβαση",
    "File not found" : "Το αρχείο δεν βρέθηκε",
    "The specified document has not been found on the server." : "Το συγκεκριμένο έγγραφο δεν έχει βρεθεί στο διακομιστή.",
    "You can click here to return to %s." : "Μπορείτε να κάνετε κλικ εδώ για να επιστρέψετε στο %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Γειά χαρά,\n\nαπλά σας ενημερώνω πως ο %s μοιράστηκε το %s με εσάς.\nΔείτε το: %s\n\n",
    "The share will expire on %s." : "Ο διαμοιρασμός θα λήξει σε %s.",
    "Cheers!" : "Χαιρετισμούς!",
    "Internal Server Error" : "Εσωτερικό Σφάλμα Διακομιστή",
    "The server encountered an internal error and was unable to complete your request." : "Ο διακομιστής αντιμετώπισε ένα εσωτερικό σφάλμα και δεν μπόρεσε να ολοκληρώσει το αίτημά σας.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Παρακαλώ επικοινωνήστε με το διαχειριστή του διακομιστή, εάν αυτό το σφάλμα επανεμφανίζεται πολλές φορές, παρακαλούμε να συμπεριλάβετε τις τεχνικές λεπτομέρειες παρακάτω στην αναφορά σας.",
    "More details can be found in the server log." : "Περισσότερες λεπτομέρειες μπορείτε να βρείτε στο αρχείο καταγραφής του διακομιστή.",
    "Technical details" : "Τεχνικές λεπτομέρειες",
    "Remote Address: %s" : "Απομακρυσμένη Διεύθυνση: %s",
    "Request ID: %s" : "Αίτημα ID: %s",
    "Type: %s" : "Τύπος: %s",
    "Code: %s" : "Κωδικός: %s",
    "Message: %s" : "Μήνυμα: %s",
    "File: %s" : "Αρχείο: %s",
    "Line: %s" : "Γραμμή: %s",
    "Trace" : "Ανίχνευση",
    "Security warning" : "Προειδοποίηση Ασφαλείας",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ο κατάλογος δεδομένων και τα αρχεία σας είναι πιθανό προσβάσιμα από το internet γιατί δεν δουλεύει το αρχείο .htaccess.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Για πληροφορίες πως να ρυθμίσετε ορθά τον διακομιστή σας, παρακαλώ δείτε την <a href=\"%s\" target=\"_blank\">τεκμηρίωση</a>.",
    "Create an <strong>admin account</strong>" : "Δημιουργήστε έναν <strong>λογαριασμό διαχειριστή</strong>",
    "Username" : "Όνομα χρήστη",
    "Storage & database" : "Αποθήκευση & βάση δεδομένων",
    "Data folder" : "Φάκελος δεδομένων",
    "Configure the database" : "Ρύθμιση της βάσης δεδομένων",
    "Only %s is available." : "Μόνο %s είναι διαθέσιμο.",
    "Install and activate additional PHP modules to choose other database types." : "Εγκαταστήστε και ενεργοποιείστε επιπλέον αρθρώματα PHP για να επιλέξετε άλλους τύπους βάσεων δεδομένων.",
    "For more details check out the documentation." : "Για περισσότερες πληροφορίες ανατρέξτε στην τεκμηρίωση.",
    "Database user" : "Χρήστης της βάσης δεδομένων",
    "Database password" : "Συνθηματικό βάσης δεδομένων",
    "Database name" : "Όνομα βάσης δεδομένων",
    "Database tablespace" : "Κενά Πινάκων Βάσης Δεδομένων",
    "Database host" : "Διακομιστής βάσης δεδομένων",
    "Performance warning" : "Προειδοποίηση απόδοσης",
    "SQLite will be used as database." : "Η SQLite θα χρησιμοποιηθεί ως βάση δεδομένων.",
    "For larger installations we recommend to choose a different database backend." : "Για μεγαλύτερες εγκαταστάσεις συνιστούμε να επιλέξετε διαφορετικό σύστημα υποστήριξης βάσης δεδομένων.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Ειδικά όταν χρησιμοποιείτε τον πελάτη για συγχρονισμό στον υπολογιστή σας, δεν συνίσταται η χρήση της SQLite.",
    "Finish setup" : "Ολοκλήρωση εγκατάστασης",
    "Finishing …" : "Ολοκλήρωση...",
    "Need help?" : "Θέλετε βοήθεια;",
    "See the documentation" : "Δείτε την τεκμηρίωση",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Γειά χαρά,<br><br>απλά σας ενημερώνω πως ο %s μοιράστηκε το<strong>%s</strong> με εσάς.<br><a href=\"%s\">Δείτε το!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Αυτή η εφαρμογή απαιτεί JavaScript για σωστή λειτουργία. Παρακαλώ {linkstart} ενεργοποιήστε τη JavaScrip {linkend} και επαναφορτώστε τη σελίδα.",
    "Log out" : "Αποσύνδεση",
    "Search" : "Αναζήτηση",
    "Server side authentication failed!" : "Η διαδικασία επικύρωσης απέτυχε από την πλευρά του διακομιστή!",
    "Please contact your administrator." : "Παρακαλώ επικοινωνήστε με τον διαχειριστή.",
    "An internal error occured." : "Παρουσιάστηκε εσωτερικό σφάλμα.",
    "Please try again or contact your administrator." : "Παρακαλώ δοκιμάστε ξανά ή επικοινωνήστε με τον διαχειριστή σας.",
    "Log in" : "Είσοδος",
    "Wrong password. Reset it?" : "Λάθος Κωδικός. Επαναφορά;",
    "Stay logged in" : "Μείνετε συνδεδεμένος",
    "Alternative Logins" : "Εναλλακτικές Συνδέσεις",
    "Use the following link to reset your password: {link}" : "Χρησιμοποιήστε τον ακόλουθο σύνδεσμο για να επανεκδόσετε τον κωδικό: {link}",
    "New password" : "Νέο συνθηματικό",
    "New Password" : "Νέος Κωδικός",
    "Reset password" : "Επαναφορά συνθηματικού",
    "This ownCloud instance is currently in single user mode." : "Αυτή η εγκατάσταση ownCloud είναι τώρα σε κατάσταση ενός χρήστη.",
    "This means only administrators can use the instance." : "Αυτό σημαίνει ότι μόνο διαχειριστές μπορούν να χρησιμοποιήσουν την εγκατάσταση.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Επικοινωνήστε με το διαχειριστή του συστήματος αν αυτό το μήνυμα συνεχίζει να εμφανίζεται ή εμφανίστηκε απρόσμενα.",
    "Thank you for your patience." : "Σας ευχαριστούμε για την υπομονή σας.",
    "You are accessing the server from an untrusted domain." : "Η προσπέλαση του διακομιστή γίνεται από μη έμπιστο τομέα.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Παρακαλώ επικοινωνήστε με το διαχειριστή του συστήματος. Αν είστε ο διαχειριστής, ρυθμίστε την επιλογή \"trusted_domain\" στο αρχείο config/config.php. Μπορείτε να βρείτε παράδειγμα στο αρχείο config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Ανάλογα με τις ρυθμίσεις σας, σαν διαχειριστής θα μπορούσατε επίσης να χρησιμοποιήσετε το παρακάτω κουμπί για να εμπιστευθείτε αυτή την περιοχή.",
    "Add \"%s\" as trusted domain" : "Προσθήκη \"%s\" ως αξιόπιστη περιοχή",
    "App update required" : "Απαιτείται ενημέρωση εφαρμογής",
    "%s will be updated to version %s" : "%s θα αναβαθμιστεί σε έκδοση %s",
    "These apps will be updated:" : "Αυτές οι εφαρμογές θα αναβαθμιστούν:",
    "These incompatible apps will be disabled:" : "Αυτές οι μη συμβατές εφαρμογές θα απενεργοποιηθούν:",
    "The theme %s has been disabled." : "Το θέμα %s έχει απενεργοποιηθεί.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Παρακαλώ βεβαιωθείτε ότι έχουν ληψθεί αντίγραφα ασφαλείας της βάσης δεδομένων, του φακέλου ρυθμίσεων και του φακέλου δεδομένων πριν προχωρήσετε.",
    "Start update" : "Έναρξη ενημέρωσης",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Για να αποφύγετε τη λήξη χρόνου με μεγαλύτερες εγκαταστάσεις, μπορείτε αντί αυτού να τρέξετε την ακόλουθη εντολή από τον κατάλογο αρχείων εφαρμογών:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Αυτή %s η εγκατάσταση είναι σε κατάσταση συντήρησης, η οποία μπορεί να πάρει κάποιο χρόνο.",
    "This page will refresh itself when the %s instance is available again." : "Αυτή η σελίδα θα ανανεωθεί από μόνη της όταν η %s εγκατάσταση είναι διαθέσιμη ξανά.",
    "Error loading file picker template: {error}" : "Σφάλμα κατά την φόρτωση προτύπου επιλογέα αρχείων: {σφάλμα}",
    "Password can not be changed. Please contact your administrator." : "Ο κωδικός πρόσβασης δεν μπορεί να αλλάξει. Παρακαλώ επικοινωνήστε με το διαχειριστή σας."
},
"nplurals=2; plural=(n != 1);");
